1#ifndef __MATH_MATH_KERNEL_H__
2#define __MATH_MATH_KERNEL_H__
48 for (
int i = idx;
i < n;
i +=
str) {
91 const int ly,
const int lz) {
92 const int idx2 = idx - 1;
93 index[3] =
idx2 / (lx * ly * lz);
94 index[2] = (
idx2 - (lx * ly * lz) * index[3]) / (lx * ly);
95 index[1] = (
idx2 - (lx * ly * lz) * index[3] - (lx * ly) * index[2]) / lx;
96 index[0] = (
idx2 - (lx * ly * lz) * index[3] - (lx * ly) * index[2]) -
106 const int n1,
const int n2,
const int nf) {
107 return ((
i) + (n1) * (((
j) - 1) + (n2) * (((
k) - 1) + (
nf) * (((l) - 1))))) - 1;
113template<
typename T >
129 for (
int m = idx; m <
n_mask; m +=
str) {
130 const int f = facet[m + 1];
153template<
typename T >
171template<
typename T >
189template<
typename T >
208template<
typename T >
226template<
typename T >
244template<
typename T >
260template<
typename T >
269 for (
int i = idx;
i < n;
i +=
str) {
277template<
typename T >
285 for (
int i = idx;
i < n;
i +=
str) {
293template<
typename T >
302 for (
int i = idx;
i < n;
i +=
str) {
310template<
typename T >
318 for (
int i = idx;
i < n;
i +=
str) {
326template<
typename T >
335 for (
int i = idx;
i < n;
i +=
str) {
343template<
typename T >
353 for (
int i = idx;
i < n;
i +=
str) {
361template<
typename T >
368 for (
int i = idx;
i < n;
i +=
str) {
376template<
typename T >
385 for (
int i = idx;
i < n;
i +=
str) {
393template<
typename T >
401 for (
int i = idx;
i < n;
i +=
str) {
409template<
typename T >
417 for (
int i = idx;
i < n;
i +=
str) {
425template<
typename T >
433 for (
int i = idx;
i < n;
i +=
str) {
441template<
typename T >
450 for (
int i = idx;
i < n;
i +=
str) {
458template<
typename T >
468 for (
int i = idx;
i < n;
i +=
str) {
469 a[
i] = b[
i] + c[
i] + d[
i];
476template<
typename T >
485 for (
int i = idx;
i < n;
i +=
str) {
493template<
typename T >
504 for (
int i = idx;
i < n;
i+=
str) {
507 tmp += p[
j][
i]*alpha[
j];
516template<
typename T >
525 for (
int i = idx;
i < n;
i +=
str) {
533template<
typename T >
542 for (
int i = idx;
i < n;
i +=
str) {
550template<
typename T >
561 for (
int i = idx;
i < n;
i +=
str) {
569template<
typename T >
582 for (
int i = idx;
i < n;
i +=
str) {
590template<
typename T >
605 for (
int i = idx;
i < n;
i +=
str) {
613template<
typename T >
621 for (
int i = idx;
i < n;
i +=
str) {
629template<
typename T >
637 for (
int i = idx;
i < n;
i +=
str) {
645template<
typename T >
654 for (
int i = idx;
i < n;
i +=
str) {
662template<
typename T >
670 for (
int i = idx;
i < n;
i +=
str) {
678template<
typename T >
687 for (
int i = idx;
i < n;
i +=
str) {
695template<
typename T >
704 for (
int i = idx;
i < n;
i +=
str) {
705 a[
i] =
a[
i] - b[
i] * c[
i];
712template<
typename T >
720 for (
int i = idx;
i < n;
i +=
str) {
728template<
typename T >
737 for (
int i = idx;
i < n;
i +=
str) {
745template<
typename T >
754 for (
int i = idx;
i < n;
i +=
str) {
755 a[
i] =
a[
i] + b[
i] * c[
i];
763template<
typename T >
773 for (
int i = idx;
i < n;
i +=
str) {
774 a[
i] =
a[
i] + b[
i] * c[
i] * d[
i];
782template<
typename T >
792 for (
int i = idx;
i < n;
i +=
str) {
793 a[
i] =
a[
i] + s * b[
i] * c[
i];
801template<
typename T >
814 for (
int i = idx;
i < n;
i +=
str) {
823template<
typename T >
838 for (
int i = idx;
i < n;
i +=
str) {
841 u3[
i] = v1[
i]*w2[
i] - v2[
i]*w1[
i];
890template<
typename T >
896 for (
int i = idx;
i<n ;
i +=
str)
921template<
typename T >
927 for (
int i = idx;
i<n ;
i +=
str)
952template<
typename T >
958 for (
int i = idx;
i<n ;
i +=
str)
984template<
typename T_acc >
995 for (
int i=idx ;
i<n ;
i+=step)
1018template<
typename T >
1033 for (
int i = idx;
i < n;
i+=
str) {
1053template<
typename T,
typename T_acc >
1068 for (
int i = idx;
i < n;
i+=
str) {
1088template<
typename T,
typename T_acc >
1103 for (
int i = idx;
i < n;
i+=
str) {
1129template<
typename T,
typename T_acc >
1143 for (
int i = idx;
i < n;
i+=
str) {
1164template<
typename T,
typename T_acc >
1178 for (
int i = idx;
i < n;
i+=
str) {
1199template<
typename T,
typename T_acc >
1212 for (
int i = idx;
i<n ;
i +=
str)
1234template<
typename T >
1248 for (
int i = idx;
i<n ;
i +=
str)
1270template<
typename T >
1284 for (
int i = idx;
i<n ;
i +=
str)
1306template<
typename T >
1313 for (
int i = idx;
i < n;
i +=
str) {
1325template <
typename T>
1339template <
typename T>
1354template <
typename T>
1367template <
typename T>
1374 for (
int i = idx;
i < n;
i +=
str)
a[
i] =
max(b[
i], c);
1381template <
typename T>
1395template <
typename T>
1410template <
typename T>
1423template <
typename T>
1430 for (
int i = idx;
i < n;
i +=
str)
a[
i] =
min(b[
i], c);
__global__ void ale_add_kinematics_kernel(const int n, T *__restrict__ wx, T *__restrict__ wy, T *__restrict__ wz, const T *__restrict__ x_ref, const T *__restrict__ y_ref, const T *__restrict__ z_ref, const T *__restrict__ phi, const T *__restrict__ x, const T *__restrict__ y, const T *__restrict__ z, const kinematics_params_t kin_params)
__global__ void const T *__restrict__ x
__global__ void const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ const T *__restrict__ w3
__global__ void addcol4_kernel(T *__restrict__ a, const T *__restrict__ b, const T *__restrict__ c, const T *__restrict__ d, const int n)
__global__ void cwrap_kernel(T *__restrict__ a, const T min_val, const T max_val, const int n)
__global__ void pwmin_vec3_kernel(T *__restrict__ a, const T *__restrict__ b, const T *__restrict__ c, const int n)
__global__ void reduce_kernel(T *bufred, const int n)
__global__ void cdiv2_kernel(T *__restrict__ a, T *__restrict__ b, const T c, const int n)
__global__ void invcol2_kernel(T *__restrict__ a, const T *__restrict__ b, const int n)
__global__ void add2_kernel(T *__restrict__ a, const T *__restrict__ b, const int n)
__global__ void add4s3_kernel(T *__restrict__ a, const T *__restrict__ b, const T *__restrict__ c, const T *__restrict__ d, const T c1, const T c2, const T c3, const int n)
__inline__ __device__ T reduce_warp(T val)
__global__ void masked_scatter_copy_aligned_kernel(T *__restrict__ a, T *__restrict__ b, int *__restrict__ mask, const int n, const int n_mask)
__global__ void masked_atomic_reduction_kernel(T *__restrict__ a, T *__restrict__ b, int *__restrict__ mask, const int n, const int m)
__global__ void pwmax_vec3_kernel(T *__restrict__ a, const T *__restrict__ b, const T *__restrict__ c, const int n)
__global__ void glsc2_kernel(const T *a, const T *b, T_acc *buf_h, const int n)
__global__ void addcol3s2_kernel(T *__restrict__ a, const T *__restrict__ b, const T *__restrict__ c, const T s, const int n)
__global__ void cfill_mask_kernel(T *__restrict__ a, const T c, const int size, int *__restrict__ mask, const int mask_size)
__global__ void cdiv_kernel(T *__restrict__ a, const T c, const int n)
__global__ void masked_copy_kernel_aligned(T *__restrict__ a, T *__restrict__ b, int *__restrict__ mask, const int n, const int n_mask)
__global__ void face_masked_gather_copy_kernel(T *__restrict__ a, const T *__restrict__ b, const int *__restrict__ mask, const int *__restrict__ facet, const int n1, const int n2, const int lx, const int ly, const int lz, const int n_mask)
__global__ void masked_gather_copy_aligned_kernel(T *__restrict__ a, T *__restrict__ b, int *__restrict__ mask, const int n, const int n_mask)
__global__ void pwmax_sca2_kernel(T *__restrict__ a, const T c, const int n)
__device__ __forceinline__ void face_gather_nonlinear_index(int *index, const int idx, const int lx, const int ly, const int lz)
__global__ void reduce_max_kernel(T *bufred, const T ninf, const int n)
__global__ void pwmin_vec2_kernel(T *__restrict__ a, const T *__restrict__ b, const int n)
__global__ void add3s2_kernel(T *__restrict__ a, const T *__restrict__ b, const T *__restrict__ c, const T c1, const T c2, const int n)
__inline__ __device__ T reduce_max_warp(T val)
__global__ void glsum_kernel(const T *a, T_acc *buf_h, const int n)
__global__ void add2s1_kernel(T *__restrict__ a, const T *__restrict__ b, const T c1, const int n)
__device__ __forceinline__ int face_gather_idx(const int i, const int j, const int k, const int l, const int n1, const int n2, const int nf)
__global__ void add5s4_kernel(T *__restrict__ a, const T *__restrict__ b, const T *__restrict__ c, const T *__restrict__ d, const T *__restrict__ e, const T c1, const T c2, const T c3, const T c4, const int n)
__global__ void masked_gather_copy_kernel(T *__restrict__ a, T *__restrict__ b, int *__restrict__ mask, const int n, const int n_mask)
__global__ void add2s2_many_kernel(T *__restrict__ x, const T **p, const T *alpha, const int p_cur, const int n)
__global__ void glsc3_many_kernel(const T *a, const T **b, const T *c, T_acc *buf_h, const int j, const int n)
__global__ void pwmax_vec2_kernel(T *__restrict__ a, const T *__restrict__ b, const int n)
__global__ void cmult_kernel(T *__restrict__ a, const T c, const int n)
__global__ void addcol3_kernel(T *__restrict__ a, const T *__restrict__ b, const T *__restrict__ c, const int n)
__global__ void pwmin_sca3_kernel(T *__restrict__ a, const T *__restrict b, const T c, const int n)
__global__ void pwmax_sca3_kernel(T *__restrict__ a, const T *__restrict b, const T c, const int n)
__global__ void power_kernel(T *__restrict__ ap, const T *__restrict__ a, const T p, const int n)
__global__ void col2_kernel(T *__restrict__ a, const T *__restrict__ b, const int n)
__global__ void masked_copy_kernel_0(T *__restrict__ a, T *__restrict__ b, int *__restrict__ mask, const int n, const int n_mask)
__global__ void sqrt_inplace_kernel(T *__restrict__ a, const int n)
__global__ void col3_kernel(T *__restrict__ a, const T *__restrict__ b, const T *__restrict__ c, const int n)
__global__ void sub2_kernel(T *__restrict__ a, const T *__restrict__ b, const int n)
__global__ void glmin_kernel(const T *a, const T pinf, T *buf_h, const int n)
__global__ void cmult2_kernel(T *__restrict__ a, T *__restrict__ b, const T c, const int n)
__global__ void pwmin_sca2_kernel(T *__restrict__ a, const T c, const int n)
__global__ void sub3_kernel(T *__restrict__ a, const T *__restrict__ b, const T *__restrict__ c, const int n)
__global__ void glsubnorm2_kernel(const T *a, const T *b, T_acc *buf_h, const int n)
__global__ void glsc3_reduce_kernel(T_acc *bufred, const int n, const int j)
__global__ void add2s2_kernel(T *__restrict__ a, const T *__restrict__ b, const T c1, const int n)
__global__ void vdot3_kernel(T *__restrict__ dot, const T *__restrict__ u1, const T *__restrict__ u2, const T *__restrict__ u3, const T *__restrict__ v1, const T *__restrict__ v2, const T *__restrict__ v3, const int n)
__global__ void invcol1_kernel(T *__restrict__ a, const int n)
__global__ void add3_kernel(T *__restrict__ a, const T *__restrict__ b, const T *__restrict__ c, const int n)
__global__ void glmax_kernel(const T *a, const T ninf, T *buf_h, const int n)
__global__ void vlsc3_kernel(const T *a, const T *b, const T *c, T *buf_h, const int n)
__global__ void add4_kernel(T *__restrict__ a, const T *__restrict__ b, const T *__restrict__ c, const T *__restrict__ d, const int n)
__global__ void cfill_kernel(T *__restrict__ a, const T c, const int n)
__global__ void masked_scatter_copy_kernel(T *__restrict__ a, T *__restrict__ b, int *__restrict__ mask, const int n, const int n_mask)
__global__ void glsc3_kernel(const T *a, const T *b, const T *c, T_acc *buf_h, const int n)
__global__ void reduce_min_kernel(T *bufred, const T pinf, const int n)
__global__ void vcross_kernel(T *__restrict__ u1, T *__restrict__ u2, T *__restrict__ u3, const T *__restrict__ v1, const T *__restrict__ v2, const T *__restrict__ v3, const T *__restrict__ w1, const T *__restrict__ w2, const T *__restrict__ w3, const int n)
__global__ void addsqr2s2_kernel(T *__restrict__ a, const T *__restrict__ b, const T c1, const int n)
__global__ void cadd2_kernel(T *__restrict__ a, T *__restrict__ b, const T c, const int n)
__global__ void absval_kernel(T *__restrict__ a, const int n)
__global__ void invcol3_kernel(T *__restrict__ a, const T *__restrict__ b, const T *__restrict__ c, const int n)
__global__ void subcol3_kernel(T *__restrict__ a, const T *__restrict__ b, const T *__restrict__ c, const int n)
__global__ void cadd_kernel(T *__restrict__ a, const T c, const int n)
__inline__ __device__ T reduce_min_warp(T val)
__global__ void copy_kernel(T *__restrict__ a, const T *__restrict__ b, const int n)
Object for handling masks in Neko.